@@ -36,10 +36,10 @@
 
 #include <libhildonwm/hd-wm.h>
 
-#include "hildon-home-area.h"
-#include "hildon-home-applet.h"
-#include "hildon-home-titlebar.h"
-#include "hildon-home-window.h"
+#include <libhildondesktop/hildon-home-area.h>
+#include <libhildondesktop/hildon-desktop-home-item.h>
+#include <libhildondesktop/hildon-home-titlebar.h>
+#include <libhildondesktop/hildon-home-window.h>
 
 
 #define HH_AREA_CONFIGURATION_FILE        ".osso/hildon-desktop/home-layout.conf"
@@ -122,8 +122,13 @@ area_add (HildonHomeArea   *area,
           HildonHomeWindow *window)
 {
   HildonHomeWindowPrivate *priv = window->priv;
+  gboolean layout_mode_sucks;
 
-  if (HILDON_IS_HOME_AREA (priv->applet_area))
+  g_object_get (applet,
+                "layout-mode-sucks", &layout_mode_sucks,
+                NULL);
+
+  if (HILDON_IS_HOME_AREA (priv->applet_area) && !layout_mode_sucks)
     {
       HildonHomeArea *area =  HILDON_HOME_AREA (priv->applet_area);
 
@@ -230,7 +235,7 @@ hildon_home_window_background (HildonHomeWindow   *window,
         }
 
       gtk_container_foreach (GTK_CONTAINER (priv->applet_area),
-                             (GtkCallback)hildon_home_applet_set_is_background,
+                             (GtkCallback)hildon_desktop_home_item_set_is_background,
                              (gpointer)is_background);
     }
 }
@@ -246,7 +251,7 @@ hildon_home_window_system_inactivity (HildonHomeWindow   *window,
   priv->is_inactive = is_inactive;
 
   gtk_container_foreach (GTK_CONTAINER (priv->applet_area),
-                         (GtkCallback)hildon_home_applet_set_is_background,
+                         (GtkCallback)hildon_desktop_home_item_set_is_background,
                          (gpointer)is_inactive);
 }
 
